@@ -222,6 +222,29 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateEmbedWebUrl(self, request):
+        """本接口（CreateEmbedWebUrl）用于创建嵌入web的链接 本接口支持创建：创建印章，创建模板，修改模板，预览模板，预览合同流程的web链接 进入web连接后与当前控制台操作保持一致
+
+        :param request: Request instance for CreateEmbedWebUrl.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateEmbedWebUrlRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateEmbedWebUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateEmbedWebUrl", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateEmbedWebUrlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateFlow(self, request):
         """通过模板创建签署流程<br/>
         适用场景：在标准制式的合同场景中，可通过提前预制好模板文件，每次调用模板文件的id，补充合同内容信息及签署信息生成电子合同。<br/>
@@ -429,8 +452,10 @@ class EssClient(AbstractClient):
 
 
     def CreateFlowSignUrl(self, request):
-        """创建个人H5签署链接，请联系客户经理申请使用 <br/>
-        该接口用于发起合同后，生成C端签署人的签署链接 <br/>
+        """创建个人H5签署链接，请联系客户经理申请开通使用, 否则调用会返回失败 <br/>
+
+        该接口用于发起合同后，生成个人签署人的签署链接, 暂时不支持企业端签署 <br/>
+
         注意：该接口目前签署人类型仅支持个人签署方（PERSON） <br/>
         注意：该接口可生成签署链接的C端签署人必须仅有手写签名和时间类型的签署控件<br/>
         注意：该接口返回的签署链接是用于APP集成的场景，支持APP打开或浏览器直接打开，不支持微信小程序嵌入。微信小程序请使用小程序跳转或半屏弹窗的方式<br/>
@@ -555,6 +580,30 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateOrganizationBatchSignUrl(self, request):
+        """通过此接口，创建企业批量签署链接，企业员工点击链接即可跳转控制台进行批量签署。
+        如果没有UserId，Name和Mobile必填，对应的员工必须在企业下已经实名，且该员工为批量签署合同中的签署方。
+
+        :param request: Request instance for CreateOrganizationBatchSignUrl.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateOrganizationBatchSignUrlRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateOrganizationBatchSignUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOrganizationBatchSignUrl", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateOrganizationBatchSignUrlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreatePrepareFlow(self, request):
         """创建快速发起流程
         适用场景：用户通过API 合同文件及签署信息，并可通过我们返回的URL在页面完成签署控件等信息的编辑与确认，快速发起合同.
@@ -728,6 +777,29 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateWebThemeConfig(self, request):
+        """用来创建页面主题配置
+
+        :param request: Request instance for CreateWebThemeConfig.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateWebThemeConfigRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateWebThemeConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateWebThemeConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateWebThemeConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteIntegrationDepartment(self, request):
         """通过此接口，删除企业的部门。
 
@@ -963,8 +1035,18 @@ class EssClient(AbstractClient):
 
 
     def DescribeFlowTemplates(self, request):
-        """当模板较多或模板中的控件较多时，可以通过查询模板接口更方便的获取模板列表，以及每个模板内的控件信息。<br/>
-        该接口常用来配合“创建电子文档”接口作为前置的接口使用。<br/>
+        """本接口用于查询本企业模板列表。
+
+        当模板较多或模板中的控件较多时，可以通过查询模板接口更方便的获取模板列表，以及每个模板内的控件信息。
+
+        > **适用场景**
+        >  该接口常用来配合“模板发起合同-创建电子文档”接口作为前置的接口使用。
+        >  一个模板通常会包含以下结构信息
+        >- 模板基本信息
+        >- 发起方参与信息Promoter、签署参与方 Recipients，后者会在模板发起合同时用于指定参与方
+        >- 填写控件 Components
+        >- 签署控件 SignComponents
+        >- 生成模板的文件基础信息 FileInfos
 
         :param request: Request instance for DescribeFlowTemplates.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeFlowTemplatesRequest`
@@ -1033,7 +1115,9 @@ class EssClient(AbstractClient):
 
 
     def DescribeIntegrationMainOrganizationUser(self, request):
-        """通过子企业影子账号查询主企业员工账号
+        """集团企业统一使用主代子进行操作，无需根据子企业账号进行转化查询，该接口需要屏蔽下线
+
+        通过子企业影子账号查询主企业员工账号
 
         :param request: Request instance for DescribeIntegrationMainOrganizationUser.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeIntegrationMainOrganizationUserRequest`
